package admin_role

import (
	"github.com/gin-gonic/gin"
	"net/http"
	"sghgogs.com/micro/auth-client/response"
	"sghgogs.com/micro/auth-client/utils"
	pb "sghgogs.com/micro/auth-service/proto"
)

type EnabledRoleItem struct {
	ID          int64  `json:"id"`
	Name        string `json:"name"`
	Description string `json:"description"`
}

type EnabledRoles struct {
	Roles []EnabledRoleItem `json:"roles"`
}

// RetrieveEnabledRoles
// @summary 已启用角色列表
// @Description 获取所有已启用角色列表
// @Tags Role 角色管理
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Success 200 {object} response.ApiResponse{data=EnabledRoles} "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /v1/api/admin/role/labels [get]
func (svc *ApiAdminRole) RetrieveEnabledRoles(c *gin.Context) {
	ctx, _ := utils.CreateContextWithToken(c, "authorizationservice", "AdminRoleService.RetrieveEnabledRoles")
	roles, err := svc.Service.RetrieveEnabledRoles(ctx, &pb.RetrieveEnabledRolesRequest{})
	if err != nil {
		code, mgs := response.MicroErrorRequest(err)
		c.JSON(code, response.ErrorResponse(code, mgs))
		return
	}
	c.JSON(http.StatusOK, response.SuccessResponse(roles))
}
