package admin_user

import (
	"github.com/gin-gonic/gin"
	"net/http"
	"sghgogs.com/micro/auth-client/response"
	"sghgogs.com/micro/auth-client/utils"
	pb "sghgogs.com/micro/auth-service/proto"
)

type EnabledUserItem struct {
	ID   int64  `json:"id"`
	Name string `json:"name"`
}

type EnabledUsers struct {
	Roles []EnabledUserItem `json:"roles"`
}

// RetrieveEnabledUsers
// @summary 已启用 用户列表
// @Description 获取所有已启用 用户列表
// @Tags User 用户管理
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Success 200 {object} response.ApiResponse{data=[]EnabledUserItem} "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /v1/api/admin/user/labels [get]
func (svc *ApiAdminUser) RetrieveEnabledUsers(c *gin.Context) {
	ctx, _ := utils.CreateContextWithToken(c, "authorizationservice", "AdminUserService.RetrieveEnabledUsers")
	users, err := svc.Service.RetrieveEnabledUsers(ctx, &pb.RetrieveEnabledUsersRequest{})
	if err != nil {
		code, mgs := response.MicroErrorRequest(err)
		c.JSON(code, response.ErrorResponse(code, mgs))
		return
	}
	items := make([]EnabledUserItem, 0)
	for _, user := range users.Users {
		items = append(items, EnabledUserItem{
			ID:   user.Id,
			Name: user.Username,
		})
	}
	c.JSON(http.StatusOK, response.SuccessResponse(items))
}
